@@ -1,3 +1,4 @@
+import logging
 import traceback
 
 import ssl
@@ -29,12 +30,19 @@ cipher_list = "ECDH+ECDSA+AESGCM:" \
 
 
 def read_ssl_request(context: Context):
-    ssl_request = SSLRequest.read(context.input)
+    logging.error("read_ssl_requst")
+    try:
+        ssl_request = SSLRequest.read(context.input)
+        logging.error(ssl_request)
 
-    if context.key_file and context.cert_file:
-        return context.update_mem('ssl_request', ssl_request), Names.WRITE_SSL_YES
-    else:
-        return context.update_mem('ssl_request', ssl_request), Names.WRITE_SSL_NO
+        if context.key_file and context.cert_file:
+            return context.update_mem('ssl_request', ssl_request), Names.WRITE_SSL_YES
+        else:
+            return context.update_mem('ssl_request', ssl_request), Names.WRITE_SSL_NO
+    except Exception as e:
+        log_exception(e)
+        logging.error("Error while processing ssl request, downgrading to SSL_NO")
+        return context, Names.WRITE_SSL_NO
 
 
 def write_ssl_resp_no(context: Context):
